@@ -1,6 +1,6 @@
 
 from .logical import TRUE, true, T, FALSE, F, false, NULL
-from .little impoty is_number, is_odd, is_even
+from .little import is_number, is_odd, is_even
 
 from .r_funcs import nrow, ncol, colMeans, rowMeans, colSums, rowSums, apply, lapply, sapply, sample, sample_int
 
